#ifndef AtomData_h
#define AtomData_h

// $Id: AtomData.h,v 1.6 2014/04/27 19:27:57 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QHash>
#include <QObject>
#include <QString>
#include <QSharedPointer>

// forward declaration
class XcbProperties;

//! atom data class
class AtomData: public QObject, public Counter
{

    public:

    typedef QSharedPointer<AtomData> Pointer;
    typedef QHash<QString, AtomData::Pointer> Hash;

    //! constructor
    AtomData( void ):
        QObject(),
        Counter( "AtomData" ),
        itemCount_( 0 ),
        length_( 0 ),
        format_( 0 ),
        data_( 0L )
    {}

    //! destructor
    virtual ~AtomData( void );

    //!@name accessors
    //@{

    //! true if valid
    bool isValid( void ) const
    { return valid_; }

    //! name
    QString name( void ) const
    { return name_; }

    //! type
    QString type( void ) const
    { return type_; }

    //! items
    int itemCount( void ) const
    { return itemCount_; }

    //! length
    int length( void ) const
    { return length_; }

    //! format
    int format( void ) const
    { return format_; }

    //! data
    void* data( void ) const
    { return data_; }

    //! typed value
    QString stringValue( void ) const
    { return stringValue_; }

    //! data

    //@}

    //!@name modifiers
    //@{

    //! name
    void setName( const QString& value )
    { name_ = value; }

    //! type
    void setType( const QString& value )
    { type_ = value; }

    //! validity
    void setValid( bool value )
    { valid_ = value; }

    //! length
    void setLength( int value )
    { length_ = value; }

    //! items
    void setItemCount( int value )
    { itemCount_ = value; }

    //! format
    void setFormat( int value )
    { format_ = value; }

    //! data
    void setData( void*, int );

    //! parse
    void parse( XcbProperties* );

    //! free
    void free( void );

    //@}

    private:

    // atom name
    QString name_;

    // atom type
    QString type_;

    // items
    int itemCount_;

    // validity
    bool valid_;

    //! data length
    int length_;

    //! data format
    int format_;

    //! value
    QString stringValue_;

    // atom data
    void* data_;

};

#endif
