#ifndef AtomDataModel_h
#define AtomDataModel_h

// $Id: AtomDataModel.h,v 1.4 2014/04/25 09:12:20 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AtomData.h"
#include "Counter.h"
#include "ListModel.h"


//! Color model. Stores Color information for display in lists
class AtomDataModel : public ListModel<AtomData::Pointer>, public Counter
{
    Q_OBJECT

    public:

    //! constructor
    AtomDataModel( QObject *parent = 0 ):
        ListModel<AtomData::Pointer>( parent ),
        Counter( "AtomDataModel" )
    {}

    //! destructor
    virtual ~AtomDataModel( void )
    {}

    //! column type enumeration
    enum ColumnType
    {
        Name,
        Type,
        Count,
        Format,
        Length,
        Value,
        nColumns
    };

    //!@name methods reimplemented from base class
    //@{

    // return job for a given index
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }

    //@}

    protected:

    //! sort
    virtual void _sort( int, Qt::SortOrder = Qt::AscendingOrder );

    private:

    //! used to sort IconCaches
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //! constructor
        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
            ItemModel::SortFTor( type, order )
            {}

        //! prediction
        bool operator() ( AtomData::Pointer, AtomData::Pointer ) const;

    };

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
