// $Id: ExistingFilesDialog.cpp,v 1.4 2014/05/08 10:15:38 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ExistingFilesDialog.h"
#include "ExistingFilesDialog.moc"

#include "AnimatedTreeView.h"
#include "Debug.h"
#include "IconNames.h"
#include "IconEngine.h"
#include "XmlOptions.h"

#include <QTextStream>

//__________________________________________________
ExistingFilesDialog::ExistingFilesDialog( QWidget* parent, FileRecord::List files ):
    QuestionDialog( parent )
{

    Debug::Throw( "ExistingFilesDialog::ExistingFilesDialog.\n" );
    setWindowTitle( tr( "Save Files - Xgrabwindow" ) );

    Q_ASSERT( !files.empty() );


    if( files.size() == 1 )
    {

        setText( QString( tr( "File '%1' already exists. Do you wish to overwrite it ?" ) ).arg( files.front().file() ) );

    } else {

        setText( QString( tr( "%1 files already exist. Do you wish to overwrite them ?" ) ).arg( files.size() ) );

        AnimatedTreeView* treeView = new AnimatedTreeView( this );
        setDetails( treeView );
        treeView->setModel( &model_ );
        model_.set( files );

        // mask
        unsigned int mask(
            (1<<FileRecordModel::Filename)|
            (1<<FileRecordModel::Path ));
        treeView->setMask( mask );
        treeView->resizeColumns();

        treeView->setOptionName( "EXISTING_FILES_LIST" );

    }

    // rename buttons
    okButton().setText( tr( "Overwrite" ) );
    okButton().setIcon( IconEngine::get( IconNames::Save ) );
    adjustSize();

}
