#ifndef MainWindow_h
#define MainWindow_h

// $Id: MainWindow.h,v 1.13 2014/05/09 07:21:28 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AtomDataModel.h"
#include "BaseMainWindow.h"
#include "Counter.h"
#include "Debug.h"
#include "XcbThread.h"

#include <QAction>
#include <QBasicTimer>
#include <QStackedWidget>
#include <QTimerEvent>

class Menu;
class TreeView;
class WindowCaptureDialog;
class WindowPropertiesDisplay;
class WindowSelectionFrame;
class WindowTreeWidget;

//! color picker dialog
class MainWindow: public BaseMainWindow
{

    Q_OBJECT

    public:

    //! constructor
    MainWindow( QWidget* = 0);

    //! destructor
    virtual ~MainWindow( void );

    //!@name accessors
    //@{

    WindowSelectionFrame& windowSelectionFrame( void ) const
    { return *windowSelectionFrame_; }

    //! window tree
    WindowTreeWidget& windowTreeWidget( void ) const
    { return *windowTreeWidget_; }

    //! window capture
    WindowCaptureDialog& windowCaptureDialog( void ) const
    { return *windowCaptureDialog_; }

    //@}

    //!@name actions
    //@{

    QAction& clearAction( void ) const
    { return *clearAction_; }

    QAction& reloadAction( void ) const
    { return *reloadAction_; }

    QAction& saveIconAction( void ) const
    { return *saveIconAction_; }

    //! log action
    QAction& windowCaptureAction( void ) const
    { return *windowCaptureAction_; }

    //@}

    protected:

    //! timer event
    virtual void timerEvent( QTimerEvent* );

    //! close window event handler
    void closeEvent( QCloseEvent* );

    protected Q_SLOTS:

    //! update
    void _updateSelectedWindow( void );

    //! clear
    void _clear( void );

    //! save icon
    void _saveIcon( void );

    //! splitter moved
    void _splitterMoved( void );

    //! show window capture
    void _showWindowCaptureDialog( void );

    //! window capture dialog hidden
    void _windowCaptureDialogHidden( void );

    private Q_SLOTS:

    //! configuration
    void _updateConfiguration( void );

    private:

    //! install actions
    void _installActions( void );

    //! menu
    Menu* menu_;

    //! stacked
    QStackedWidget* stackedWidget_;

    //! window properties widget
    QWidget* windowPropertiesWidget_;

    //! clear widget
    QWidget* clearWidget_;

    //! window properties display
    WindowPropertiesDisplay* windowPropertiesDisplay_;

    //! atom data treeview
    TreeView* list_;

    //! model
    AtomDataModel model_;

    //! frame to display current color
    WindowSelectionFrame* windowSelectionFrame_;

    //! window tree widget
    WindowTreeWidget* windowTreeWidget_;

    //! window capture
    WindowCaptureDialog* windowCaptureDialog_;

    //! xcb event look
    XcbThread xcbThread_;

    //!@name actions
    //@{

    //! clear
    QAction* clearAction_;

    //! reload
    QAction* reloadAction_;

    //! save icon
    QAction* saveIconAction_;

    //! window capture action
    QAction* windowCaptureAction_;


    //@}

    //! resize timer
    /*! needed to store Keyword list width */
    QBasicTimer resizeTimer_;

};

#endif
