// $Id: WindowCaptureDialog.cpp,v 1.3 2014/05/09 07:21:28 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "WindowCaptureDialog.h"
#include "WindowCaptureDialog.moc"

#include "WindowCaptureWidget.h"

#include "IconEngine.h"
#include "IconNames.h"

#include <QShortcut>

//__________________________________________________
WindowCaptureDialog::WindowCaptureDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton|Separator )
{

    Debug::Throw( "WindowCaptureDialog::WindowCaptureDialog.\n" );
    setWindowTitle( tr( "Window Capture - Xgrabwindow" ) );

    setOptionName( "WINDOW_CAPTURE_DIALOG" );

    windowCaptureWidget_ = new WindowCaptureWidget( this );
    mainLayout().addWidget( windowCaptureWidget_ );

    // reload button
    reloadButton_ = new QPushButton( IconEngine::get( IconNames::Reload ), tr( "Reload" ), this );
    connect( reloadButton_, SIGNAL(clicked()), windowCaptureWidget_, SLOT(reload()) );
    buttonLayout().insertWidget(1, reloadButton_ );
    reloadButton_->setDefault( true );
    reloadButton_->setAutoDefault( true );

    // ok button
    connect( &okButton(), SIGNAL(pressed()), SLOT(close()) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT(close()) );

}

//_____________________________________________________________
void WindowCaptureDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "WindowCaptureDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
