#ifndef WindowCaptureWidget_h
#define WindowCaptureWidget_h

// $Id: WindowCaptureWidget.h,v 1.3 2014/05/08 11:43:57 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "WindowProperties.h"

#include <QBasicTimer>
#include <QLabel>
#include <QPaintEvent>
#include <QPixmap>
#include <QResizeEvent>
#include <QTimerEvent>
#include <QWidget>

//! tileset
namespace Private
{
    class TileSet;
}

//! show list of pending commands
class WindowCaptureWidget: public QWidget, public Counter
{

    Q_OBJECT

    public:

    //! constructor
    WindowCaptureWidget( QWidget* = 0 );

    //! destructor
    virtual ~WindowCaptureWidget( void );

    //!@name accessors
    //@{

    //! pixmap
    QPixmap pixmap( void ) const
    { return pixmap_; }

    //@}

    //!@name modifiers
    //@{

    //! clear
    void clear( void )
    { setWindowProperties( WindowProperties() ); }

    //! assign window properties
    void setWindowProperties( const WindowProperties& );

    //! update label pixmap
    void updateLabelPixmap( void );

    //@}

    public Q_SLOTS:

    //! reload
    void reload( void );

    protected:

    //! timer event
    virtual void timerEvent( QTimerEvent* );

    //! resize
    virtual void resizeEvent( QResizeEvent* );

    //! paint
    virtual void paintEvent( QPaintEvent* );

    //! create shadow pixmaps
    void _createShadowTiles( void );

    private:

    //! window
    WId window_;

    //! pixmap
    QPixmap pixmap_;

    //! label
    QLabel* label_;

    //! reload timer
    QBasicTimer timer_;

    //! shadow size
    int shadowSize_;

    //! overlap
    int overlap_;

    //! shadows
    Private::TileSet* shadowTiles_;

};

#endif
