#ifndef WindowCaptureWidget_p_h
#define WindowCaptureWidget_p_h

// $Id: WindowCaptureWidget.cpp,v 1.2 2014/05/08 11:19:00 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QPixmap>
#include <QVector>
#include <cmath>

namespace Private
{
    class TileSet
    {
        public:

        //! constructor
        TileSet(const QPixmap&, int w1, int h1, int w2, int h2 );

        //! destructor
        virtual ~TileSet()
        {}

        /*!
        Fills the specified rect with tiled chunks. Corners are never tiled,
        edges are tiled in one direction, and the center chunk is tiled in both
        directions. Partial tiles are used as needed so that the entire rect is
        perfectly filled. Filling is performed as if all chunks are being drawn.
        */
        void render(const QRect&, QPainter* ) const;

        protected:

        //! shortcut to pixmap list
        typedef QVector<QPixmap> PixmapList;

        //! initialize pixmap
        void initPixmap( PixmapList&, const QPixmap&, int w, int h, const QRect& );

        private:

        //! side extend
        /*!
        it is used to (pre) tile the side pixmaps, in order to make further tiling faster when rendering, at the cost of
        using more memory for the cache.
        */
        static int _sideExtent;

        //! pixmap arry
        PixmapList _pixmaps;

        // dimensions
        int _w1;
        int _h1;
        int _w3;
        int _h3;

    };

    //! square utility function
    static qreal square( qreal x )
    { return x*x; }

    //! functions used to draw shadows
    class Parabolic
    {
        public:

        //! constructor
        Parabolic( qreal amplitude, qreal width ):
            amplitude_( amplitude ),
            width_( width )
        {}

        //! destructor
        virtual ~Parabolic( void )
        {}

        //! value
        virtual qreal operator() ( qreal x ) const
        { return qMax( 0.0, amplitude_*(1.0 - square(x/width_) ) ); }

        private:

        qreal amplitude_;
        qreal width_;

    };

    //! functions used to draw shadows
    class Gaussian
    {
        public:

        //! constructor
        Gaussian( qreal amplitude, qreal width ):
            amplitude_( amplitude ),
            width_( width )
        {}

        //! destructor
        virtual ~Gaussian( void )
        {}

        //! value
        virtual qreal operator() ( qreal x ) const
        { return qMax( 0.0, amplitude_*(std::exp( -square(x/width_) -0.05 ) ) ); }

        private:

        qreal amplitude_;
        qreal width_;

    };

}

#endif
