#ifndef WindowProperties_h
#define WindowProperties_h

// $Id: WindowProperties.h,v 1.8 2014/05/04 11:34:55 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AtomData.h"
#include "Counter.h"

#include <QHash>
#include <QWidget>
#include <QIcon>

class XcbProperties;

class WindowProperties: public Counter
{

    public:

    //! constructor
    WindowProperties( void );

    //! constructor
    WindowProperties( WId, XcbProperties* );

    //! destructor
    virtual ~WindowProperties( void )
    {}

    //!@name accessors
    //@{

    //! validity
    bool isValid( void ) const
    { return valid_; }

    //! window id
    WId windowId( void ) const
    { return window_; }

    //! parent id
    WId parentId( void ) const
    { return parent_; }

    //! return true if selected window is root
    bool isRootWindow( void ) const;

    //! get all atoms
    const AtomData::Hash& atoms( void ) const
    { return atoms_; }

    //! name
    QString windowTitle( void ) const;

    //! class
    QString windowClass( void ) const;

    //! command
    QString command( void ) const;

    //! pid
    QString processId( void ) const;

    //! icon
    QIcon icon( void ) const;

    //! size
    QSize size( void ) const
    { return size_; }

    //! position
    QPoint position( void ) const
    { return position_; }

    //@}

    private:

    //! validity
    bool valid_;

    //! window id
    WId window_;

    //! parent
    WId parent_;

    //! size
    QSize size_;

    //! position
    QPoint position_;

    //! atom data hash
    AtomData::Hash atoms_;

};

#endif
