#ifndef WindowTreeItem_h
#define WindowTreeItem_h

// $Id: WindowTreeItem.h,v 1.3 2014/05/04 21:00:48 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "XcbUtil.h"

#include <QList>
#include <QTextStream>
#include <QWidget>

class WindowTreeItem: public Counter
{

    public:

    typedef QList<WindowTreeItem> List;

    //! flags
    enum Flag
    {
        None = 0,
        Root = 1<<0,
        Real = 1<<1
    };

    Q_DECLARE_FLAGS( Flags, Flag );

    //! constructor
    WindowTreeItem( WId id = 0, WId parentId = 0, Flags flags = None ):
        Counter( "WindowTreeItem" ),
        id_( id ),
        parentId_( parentId ),
        flags_( flags )
    {}

    //! destructor
    virtual ~WindowTreeItem( void )
    {}

    //! lower than operator
    bool operator < ( const WindowTreeItem& other ) const
    {
        return
            (parentId() < other.parentId()) ||
            (parentId() == other.parentId() && id() < other.id() );
    }

    //! equal to operator
    bool operator == ( const WindowTreeItem& other ) const
    {
        return
            parentId() == other.parentId() &&
            id() == other.id();
    }

    //!@name accessors
    //@{

    //! id
    WId id( void ) const
    { return id_; }

    //! parent
    WId parentId( void ) const
    { return parentId_; }

    //! flags
    Flags flags( void ) const
    { return flags_; }

    //! has flag
    bool hasFlag( Flag flag ) const
    { return flags_&flag; }

    //! true if is child
    bool isChild( const WindowTreeItem& other ) const
    { return parentId_ == other.id_; }

    //! window name
    const QString& windowName( void ) const
    { return windowName_; }

    //@}

    //!@name modifiers
    //@{

    //! id
    void setId( WId value )
    { id_ = value; }

    //! parent
    void setParentId( WId value )
    { parentId_ = value; }

    //! set flags
    void setFlags( Flags flags )
    { flags_ = flags; }

    //! set flag
    void setFlag( Flag flag, bool value )
    {
        if( value ) flags_ |= flag;
        else flags_ &= ~flag;
    }

    //! window name
    void setWindowName( const QString& value )
    { windowName_ = value; }

    //@}

    private:

    //! id
    WId id_;

    //! parent
    WId parentId_;

    //! window name
    QString windowName_;

    //! flags
    Flags flags_;

    //! stream operator
    friend QTextStream& operator << ( QTextStream& out, const WindowTreeItem& item )
    {
        out
            << " id: " << XcbUtil::get().windowIdString( item.id() )
            << " parent: " << XcbUtil::get().windowIdString( item.parentId() );
        return out;
    }

};

Q_DECLARE_OPERATORS_FOR_FLAGS( WindowTreeItem::Flags )

#endif
