#ifndef WindowTreeWidget_h
#define WindowTreeWidget_h

// $Id: WindowTreeWidget.h,v 1.9 2014/05/08 10:15:38 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "WindowTreeModel.h"

#include <QBasicTimer>
#include <QTimerEvent>

class TreeView;
class XcbWindowTreeParser;

//! show list of pending commands
class WindowTreeWidget: public QWidget, public Counter
{

    Q_OBJECT

    public:

    //! constructor
    WindowTreeWidget( QWidget* = 0 );

    //! destructor
    virtual ~WindowTreeWidget( void )
    {}

    //! default size
    void setDefaultWidth( int );

    //! size
    virtual QSize sizeHint( void ) const;
    
    //!@name actions
    //@{

    //! visibility
    QAction& visibilityAction( void ) const
    { return *visibilityAction_; }
    
    //! reload action
    QAction& reloadAction( void )
    { return *reloadAction_; }

    //! filter real windows
    QAction& showAllWindowsAction( void )
    { return *showAllWindowsAction_; }

    //! select window
    QAction& selectWindowAction( void )
    { return *selectWindowAction_; }
    
    //@}

    Q_SIGNALS:

    //! emitted when a window is activated
    void windowActivated( WId );

    public Q_SLOTS:

    //! set visible
    virtual void setVisible( bool );

    //! select window
    void selectWindow( WindowTreeItem );

    //! reaload on window change
    /*! this uses a timer to prevent chain reload */
    void reloadOnWindowChanged( void );

    //! reload
    void reload( void );

    protected Q_SLOTS:

    //! filter real windows
    void _toggleShowAllWindows( bool );

    //! window item activated in tree
    void _indexActivated( QModelIndex );

    //! update actions on selection change
    void _updateActions( void );
    
    //! select window from tree
    void _showWindowProperties( void );
    
    protected:

    //! timer event
    virtual void timerEvent( QTimerEvent* );

    protected Q_SLOTS:

    //! update configuration
    void _updateConfiguration( void );

    private:

    //! actions
    void _installActions( void );

    //! lists
    TreeView* list_;

    //! tree parser
    XcbWindowTreeParser* windowTreeParser_;
    
    //! model
    WindowTreeModel model_;

    //!@name actions
    //@{

    //! visibility action
    QAction* visibilityAction_;
    
    //! reload
    QAction* reloadAction_;

    //! filter real windows
    QAction* showAllWindowsAction_;
    
    //! select window action
    QAction* selectWindowAction_;

    //@}

    //! window id
    WindowTreeItem rootWindowId_;

    //! reload timer
    QBasicTimer timer_;

    //! default width;
    int defaultWidth_;

};
#endif
