// $Id: XcbThread.cpp,v 1.1 2014/05/04 11:34:55 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "XcbThread.h"
#include "XcbThread.moc"

#include "Debug.h"
#include "XcbUtil.h"

#if HAVE_X11
#include <xcb/xcb.h>
#endif

//______________________________________________________
XcbThread::XcbThread( QObject* parent ):
    QThread( parent ),
    Counter( "XcbThread" )
{
    Debug::Throw( "XcbThread::XcbThread.\n" );
    qRegisterMetaType<WId>( "WId" );
}

//______________________________________________________
void XcbThread::run( void )
{

    #if HAVE_X11
    // need to create new connection, get screen etc.
    // in order not to interfere with Qt event loop
    xcb_connection_t *connection = xcb_connect (NULL, NULL);

    // get screen and root window
    xcb_screen_t* screen = xcb_setup_roots_iterator( xcb_get_setup( connection ) ).data;
    xcb_window_t root = screen->root;

    // select events
    uint32_t mask = XCB_CW_EVENT_MASK;
    uint32_t values[1] = { XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY };
    xcb_change_window_attributes_checked(connection, root, mask, values);
    xcb_flush(connection);

    // loop over events
    xcb_generic_event_t* event = 0x0;
    while( ( event = xcb_wait_for_event( connection ) ) )
    {
        switch( event->response_type & ~0x80 )
        {
            case XCB_CREATE_NOTIFY:
            emit windowCreated( reinterpret_cast<xcb_create_notify_event_t*>(event)->window );
            break;

            case XCB_DESTROY_NOTIFY:
            emit windowDestroyed( reinterpret_cast<xcb_destroy_notify_event_t*>(event)->window );
            break;

            default: break;
        }

        free( event );
    }

    #endif

}
