// $Id: XcbWindowCapture.cpp,v 1.1 2014/05/08 10:15:38 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "XcbWindowCapture.h"
#include "XcbWindowCapture.moc"

#include "Debug.h"
#include "XcbUtil.h"

#if HAVE_X11
#include <xcb/xcb.h>
#endif

//_____________________________________________________________________
QPixmap XcbWindowCapture::capture( WId window ) const
{

    Debug::Throw() << "XcbWindowCapture::capture - " << XcbUtil::get().windowIdString( window ) << endl;
    
    #if HAVE_X11

    // connection
    xcb_connection_t* connection( XcbUtil::get().connection<xcb_connection_t>() );

    // geometry
    xcb_get_geometry_cookie_t cookie( xcb_get_geometry( connection, window ) );
    XcbUtil::ScopedPointer<xcb_get_geometry_reply_t> reply( xcb_get_geometry_reply( connection, cookie, 0x0 ) );
    if( reply ) return capture( window, QRect( QPoint(0,0), QSize( reply.data()->width, reply.data()->height ) ) );   

    #endif
    
    return QPixmap();
    
}
//_____________________________________________________________________
QPixmap XcbWindowCapture::capture( WId window, const QRect& rect ) const
{

    Debug::Throw() << "XcbWindowCapture::capture - " << XcbUtil::get().windowIdString( window ) << endl;
    if( !rect.isValid() ) return QPixmap();
    
    #if HAVE_X11

    // connection
    xcb_connection_t* connection( XcbUtil::get().connection<xcb_connection_t>() );

    // capture
    xcb_get_image_cookie_t cookie( xcb_get_image( 
        connection, XCB_IMAGE_FORMAT_Z_PIXMAP,  window, 
        rect.x(), rect.y(), rect.width(), rect.height(),
        ~0 ) );

    XcbUtil::ScopedPointer<xcb_get_image_reply_t> reply( xcb_get_image_reply( connection, cookie, 0x0 ) );
    if( reply )
    {
        QImage image( xcb_get_image_data( reply.data() ), rect.width(), rect.height(), QImage::Format_ARGB32 );
        return QPixmap::fromImage( image );
    }
    
    #endif
    
    return QPixmap();
    
}
